# Citing Dynamiqs

If you have found this library useful in your academic research, you can cite:

```bibtex
@unpublished{guilmin2024dynamiqs,
  title  = {Dynamiqs: an open-source Python library for GPU-accelerated and differentiable simulation of quantum systems},
  author = {Pierre Guilmin and Ronan Gautier and Adrien Bocquet and {\'{E}}lie Genois},
  year   = {2024},
  url    = {https://github.com/dynamiqs/dynamiqs}
}
```

> P. Guilmin, R. Gautier, A. Bocquet, E. Genois. Dynamiqs: an open-source Python library for GPU-accelerated and differentiable simulation of quantum systems (2024), in preparation.
